@@ -14,43 +14,38 @@
  * limitations under the License.
  */
 
-#ifndef GLOBUS_XIO_GSI_DRIVER_INCLUDE
-#define GLOBUS_XIO_GSI_DRIVER_INCLUDE
+#ifndef GLOBUS_XIO_GSI_DRIVER_H
+#define GLOBUS_XIO_GSI_DRIVER_H
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
  * @file globus_xio_gsi.h
+ * @brief XIO GSI Driver
  * @author Sam Meder
- * 
- * $RCSfile: globus_xio_gsi.h,v $
- * $Revision: 1.4.14.1 $
- * $Date: 2012/02/13 14:47:49 $
  */
-#endif
 
-#ifndef EXTERN_C_BEGIN
-#    ifdef __cplusplus
-#        define EXTERN_C_BEGIN extern "C" {
-#        define EXTERN_C_END }
-#    else
-#        define EXTERN_C_BEGIN
-#        define EXTERN_C_END
-#    endif
-#endif
-
-EXTERN_C_BEGIN
 
 #include "gssapi.h"
 #include "globus_common.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
+#ifndef GLOBUS_GLOBAL_DOCUMENT_SET
 /**
- * @defgroup gsi_driver Globus XIO GSI Driver
- * The GSI driver.
+ * @mainpage Globus XIO GSI Driver
+ * @copydoc globus_xio_gsi_driver
+ */
+#endif
+
+/**
+ * @defgroup globus_xio_gsi_driver Globus XIO GSI Driver
  */
 
 /**
- * @defgroup gsi_driver_instance Opening/Closing
- * @ingroup gsi_driver
+ * @addtogroup globus_xio_gsi_driver
+ * @section globus_xio_driver_instance_sect Opening/Closing
  * 
  * An XIO handle with the gsi driver can be created with either
  * globus_xio_handle_create () or globus_xio_server_register_accept ().
@@ -58,20 +53,20 @@ EXTERN_C_BEGIN
  * If the handle is created with
  * globus_xio_server_register_accept (), the
  * globus_xio_register_open () call will proceed to accept a GSSAPI
- * security context. Upon successful completion of the open, ie after
- * the open callback has been called, the application may
+ * security context. Upon successful completion of the open (after
+ * the open callback has been called) the application may
  * proceed to read or write data associated with the GSI session.
  *
  * If the handle is created with globus_xio_handle_create (), then
  * the XIO handle will implement the client-side (init) of the GSSAPI call
  * sequence and establish a security context with the accepting side indicated
  * by the contact_string passed to globus_xio_register_open ().
- *
  */
  
 /**
- * @defgroup gsi_driver_io Reading/Writing
- * @ingroup gsi_driver
+ * @addtogroup globus_xio_gsi_driver
+ * @section globus_xio_driver_readwrite_sect Reading/Writing
+ * 
  * The GSI driver behaves similar to the underlying transport driver with
  * respect to reads and writes, except for the try-read and try-write
  * operations (ie. waitforbytes ==0) which always return immediately. This is
@@ -81,8 +76,8 @@ EXTERN_C_BEGIN
  */
 
 /**
- * @defgroup gsi_driver_server Server
- * @ingroup gsi_driver
+ * @addtogroup globus_xio_gsi_driver
+ * @section globus_xio_gsi_driver_server_sect Server
  *
  * globus_xio_server_create() causes a new transport-specific
  * listener socket to be created to handle new GSI connections.
@@ -91,17 +86,17 @@ EXTERN_C_BEGIN
  * cleans up the internal resources associated with the http server
  * and calls close on the listener.
  *
- * All accepted handles inherit all gsi specific attributes set in the attr to
+ * All accepted handles inherit all GSI-specific attributes set in the attr to
  * globus_xio_server_create(), but can be overridden with the attr to 
  * globus_xio_register_open(). Furthermore, accepted handles will use the
- * GSSAPI accept security context call unless explicitly overriden during the
+ * GSSAPI accept security context call unless explicitly overridden during the
  * globus_xio_register_open() call (
  * GLOBUS_XIO_GSI_FORCE_SERVER_MODE).
  */
 
 /**
- * @defgroup gsi_driver_envs Env Variables
- * @ingroup gsi_driver
+ * @addtogroup globus_xio_gsi_driver
+ * @section globus_xio_gsi_driver_envs_sect Environment Variables
  * 
  * The gsi driver uses the following environment variables
  * - X509_USER_PROXY 
@@ -110,30 +105,25 @@ EXTERN_C_BEGIN
  * - X509_CERT_DIR
  *
  * For details see
- * <a href="http://www.globus.org/security/v2.0/env_variables.html">
- * Globus: GSI Environment Variables</a>
+ * <a href="http://toolkit.globus.org/toolkit/docs/latest-stable/gsic/pi/#gsic-pi-env">Globus: GSI Environment Variables</a>
  */
 
 /**
- * @defgroup gsi_driver_cntls Attributes and Cntls
- * @ingroup gsi_driver
+ * @addtogroup globus_xio_gsi_driver
+ * @section globus_xio_gsi_driver_cntls_sect Attributes and Cntls
  * 
- * GSI driver specific attrs and cntls.
+ * GSI driver specific attrs and cntls
  * 
  * @see globus_xio_attr_cntl ()
  * @see globus_xio_handle_cntl ()
  */
 
 /**
- * @defgroup gsi_driver_types Types
- * @ingroup gsi_driver
- */
-/**
- * @defgroup gsi_driver_errors Error Types
- * @ingroup gsi_driver
+ * @addtogroup globus_xio_gsi_driver
+ * @section globus_xio_gsi_driver_errors_sect Error Types
  * 
  * The GSI driver uses mostly GSSAPI calls, so it generally just wraps the
- * underlying GSSAPI errors or uses generic xio errors.
+ * underlying GSSAPI errors or uses generic XIO errors.
  * 
  * @see globus_xio_driver_error_match ()
  * @see globus_error_gssapi_match ()
@@ -142,12 +132,12 @@ EXTERN_C_BEGIN
 
 /**
  * GSI driver specific error types
- * @ingroup gsi_driver_errors
+ * @ingroup globus_xio_gsi_driver
  */
 typedef enum
 {
     /** Indicates that the established context does not meet the required
-     * protecetion level
+     * protection level
      */
     GLOBUS_XIO_GSI_ERROR_INVALID_PROTECTION_LEVEL,
     /** Wraps a GSSAPI error */
@@ -162,7 +152,7 @@ typedef enum
     GLOBUS_XIO_GSI_ERROR_EMPTY_HOST_NAME,
     /** Indicates that the peer is not authorized */       
     GLOBUS_XIO_GSI_AUTHORIZATION_FAILED,
-    /** Indicates the the token being read is too big. Usually happens
+    /** Indicates the token being read is too big. Usually happens
      *  when someone tries to establish a non secure session with a
      *  endpoint that expects security*/
     GLOBUS_XIO_GSI_ERROR_TOKEN_TOO_BIG
@@ -170,25 +160,27 @@ typedef enum
 
 /** doxygen varargs filter stuff
  * GlobusVarArgDefine(
- *      attr, globus_result_t, globus_xio_attr_cntl, attr, driver)
+ *      attr, globus_result_t, globus_xio_gsi_attr_cntl, attr, driver)
  * GlobusVarArgDefine(
- *      handle, globus_result_t, globus_xio_handle_cntl, handle, driver)
+ *      handle, globus_result_t, globus_xio_gsi_handle_cntl, handle, driver)
  */
 
+#define globus_xio_gsi_attr_cntl globus_xio_attr_cntl
+#define globus_xio_gsi_handle_cntl globus_xio_handle_cntl
 
 /**
  * GSI driver specific cntls
- * @ingroup gsi_driver_cntls
+ * @ingroup globus_xio_gsi_driver
  */
 typedef enum
 {
     /** GlobusVarArgEnum(attr, handle)
      * Set the credential to be used 
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param credential
      *      The credential to set. The credential structure
-     *      needs to remain valid for the lifetime of any xio datastructure it
+     *      needs to remain valid for the lifetime of any XIO data structure it
      *      is used by. 
      * @note If this is called with the handle_cntl, there must be no
      *       outstanding operations on the handle.
@@ -198,20 +190,20 @@ typedef enum
 
     /** GlobusVarArgEnum(attr, handle)
      * Get the credential to be used 
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param credential
      *      The credential that is currently set. This will only
      *      return a credential if a credential was explicitly set prior to
      *      this call. It will not return any credential automatically acquired
-     *      during context initizalization. 
+     *      during context initialization. 
      */
     /* gss_cred_id_t *                  credential */
     GLOBUS_XIO_GSI_GET_CREDENTIAL,
 
     /** GlobusVarArgEnum(attr)
      * Set the GSSAPI req_flags to be used
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param req_flags
      *      The req_flags to set
@@ -221,7 +213,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Get the GSSAPI req_flags to be used
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param req_flags
      *      The req flags currently in effect
@@ -231,7 +223,7 @@ typedef enum
     
     /** GlobusVarArgEnum(attr)
      * Set the proxy mode
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param proxy_mode
      *      The proxy mode to set
@@ -242,7 +234,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Get the proxy mode
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param proxy_mode
      *      The proxy mode that is currently in effect
@@ -253,7 +245,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Set the authorization mode
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param authz_mode
      *      The authorization mode to set
@@ -263,7 +255,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Get the authorization mode
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param authz_mode
      *      The authorization mode that is currently in effect
@@ -273,7 +265,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Set the delegation mode
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param delegation_mode
      *      The delegation mode to use
@@ -284,7 +276,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Get the delegation mode
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param delegation_mode
      *      The delegation mode currently in effect
@@ -294,7 +286,7 @@ typedef enum
     
     /** GlobusVarArgEnum(attr)
      * Make the on the wire protocol SSL compatible.
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * This implies no wrapping of security tokens and no delegation
      * 
@@ -307,7 +299,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Do anonymous authentication 
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param anon_mode
      *      The ssl compatibility mode to use
@@ -319,7 +311,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Set the wrapping mode
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * This mode determines whether tokens will be
      * wrapped with a Globus IO style header or not.
@@ -327,12 +319,12 @@ typedef enum
      * @param wrap_mode
      *      The wrapping mode to use
      */
-    /* globus_boolean_t                 wrap_mode*/
+    /* globus_bool_t                 wrap_mode*/
     GLOBUS_XIO_GSI_SET_WRAP_MODE,
 
     /** GlobusVarArgEnum(attr)
      * Get the wrapping mode
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * This mode determines whether tokens will
      * be wrapped with a Globus IO style header or not.
@@ -340,12 +332,12 @@ typedef enum
      * @param wrap_mode
      *      The wrapping mode currently in use.
      */
-    /* globus_boolean_t *               wrap_mode*/
+    /* globus_bool_t *               wrap_mode*/
     GLOBUS_XIO_GSI_GET_WRAP_MODE,
 
     /** GlobusVarArgEnum(attr)
      * Set the read buffer size
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * The read buffer is used for buffering
      * wrapped data, is initialized with a default size of 128K and scaled
@@ -359,7 +351,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Get the read buffer size
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * The read buffer is used for buffering
      * wrapped data, is initialized with a default size of 128K and scaled
@@ -373,7 +365,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Set the protection level
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param protection_level
      *      The protection level to set
@@ -384,7 +376,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Get the protection level
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param protection_level
      *      The current protection level
@@ -394,7 +386,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Set the expected peer name
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param target_name
      *      The expected peer name
@@ -404,7 +396,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Get the expected peer name
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param target_name
      *      The expected peer name
@@ -414,7 +406,7 @@ typedef enum
 
     /** GlobusVarArgEnum(handle)
      * Get the GSS context
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param context
      *      The GSS context
@@ -424,7 +416,7 @@ typedef enum
 
     /** GlobusVarArgEnum(handle)
      * Get the delegated credential
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param credential
      *      The delegated credential
@@ -434,7 +426,7 @@ typedef enum
 
     /** GlobusVarArgEnum(handle)
      * Get the name of the peer 
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param peer_name
      *      The GSS name of the peer.
@@ -444,7 +436,7 @@ typedef enum
 
     /** GlobusVarArgEnum(handle)
      * Get the GSS name associated with the local credentials
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param local_name
      *      The GSS name of the local credentials
@@ -454,12 +446,12 @@ typedef enum
 
     /** GlobusVarArgEnum(handle)
      * Initialize delegation-at-any-time process
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param credential
      *      The GSS credential to delegate
      * @param restriction_oids
-     *      The OIDS for X.509 extensions to embed in the delegated
+     *      The OIDs for X.509 extensions to embed in the delegated
      *      credential
      * @param restriction_buffers
      *      The corresponding bodies for the X.509 extensions
@@ -474,7 +466,7 @@ typedef enum
 
     /** GlobusVarArgEnum(handle)
      * Initialize non-blocking delegation-at-any-time process
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param credential
      *      The GSS credential to delegate
@@ -499,7 +491,7 @@ typedef enum
     GLOBUS_XIO_GSI_REGISTER_INIT_DELEGATION,
     /** GlobusVarArgEnum(handle)
      * Accept delegation-at-any-time process
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param credential
      *      The delegated GSS credential
@@ -519,7 +511,7 @@ typedef enum
 
     /** GlobusVarArgEnum(handle)
      * Accept non-blocking delegation-at-any-time process
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param restriction_oids
      *      The OIDS for X.509 extensions to embed in the delegated
@@ -542,7 +534,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Force the server mode setting.
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * This explicitly sets the directionality of context establishment and
      * delegation. 
@@ -555,7 +547,7 @@ typedef enum
     
     /** GlobusVarArgEnum(attr)
      * Set the allow missing signing policy flag
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param allow
      *      The flag setting to use
@@ -566,7 +558,7 @@ typedef enum
 
     /** GlobusVarArgEnum(attr)
      * Get the allow missing signing policy flag
-     * @ingroup gsi_driver_cntls
+     * @ingroup globus_xio_gsi_driver
      *
      * @param allow
      *      The flag currently set
@@ -577,7 +569,7 @@ typedef enum
 
 /**
  * Globus XIO GSI protection levels
- * @ingroup gsi_driver_types
+ * @ingroup globus_xio_gsi_driver
  */
 typedef enum
 {
@@ -591,7 +583,7 @@ typedef enum
 
 /**
  * Globus XIO GSI delegation modes
- * @ingroup gsi_driver_types
+ * @ingroup globus_xio_gsi_driver
  */
 typedef enum
 {
@@ -605,7 +597,7 @@ typedef enum
 
 /**
  * Globus XIO GSI proxy modes
- * @ingroup gsi_driver_types
+ * @ingroup globus_xio_gsi_driver
  */
 typedef enum
 {
@@ -622,7 +614,7 @@ typedef enum
 
 /**
  * Globus XIO GSI authorization modes
- * @ingroup gsi_driver_types
+ * @ingroup globus_xio_gsi_driver
  */
 typedef enum
 {
@@ -644,7 +636,7 @@ typedef enum
 
 /**
  * Globus XIO GSI init delegation callback
- * @ingroup gsi_driver_types
+ * @ingroup globus_xio_gsi_driver
  */
 typedef void (* globus_xio_gsi_delegation_init_callback_t)(
     globus_result_t			result,
@@ -652,7 +644,7 @@ typedef void (* globus_xio_gsi_delegation_init_callback_t)(
 
 /**
  * Globus XIO GSI init delegation callback
- * @ingroup gsi_driver_types
+ * @ingroup globus_xio_gsi_driver
  */
 typedef void (* globus_xio_gsi_delegation_accept_callback_t)(
     globus_result_t			result,
@@ -660,6 +652,8 @@ typedef void (* globus_xio_gsi_delegation_accept_callback_t)(
     OM_uint32                           time_rec,
     void *				user_arg);
 
-EXTERN_C_END
-
+#ifdef __cplusplus
+}
 #endif
+
+#endif /* GLOBUS_XIO_GSI_DRIVER_H */
